@@ -82,9 +82,18 @@ GstElementDetails gst_filesrc_details = {
 #define DEFAULT_BLOCKSIZE 	4*1024
 #define DEFAULT_MMAPSIZE 	4*1024*1024
 
+#ifdef G_HAVE_ISO_VARARGS
+
+/* #define fs_print(...) g_print(__VA_ARGS__)  */
+#define fs_print(...)
+
+#elif defined(G_HAVE_GNUC_VARARGS)
+
 /* #define fs_print(format,args...) g_print(format, ## args)  */
 #define fs_print(format,args...)
 
+#endif
+
 /* FileSrc signals and args */
 enum {
   /* FILL ME */
@@ -100,7 +109,7 @@ enum {
   ARG_TOUCH,
 };
 
-GST_EVENT_MASK_FUNCTION (gst_filesrc_get_event_mask,
+GST_PAD_EVENT_MASK_FUNCTION (gst_filesrc_get_event_mask,
   { GST_EVENT_SEEK, GST_SEEK_METHOD_CUR | 
 	  	    GST_SEEK_METHOD_SET | 
 		    GST_SEEK_METHOD_END | 
@@ -110,11 +119,11 @@ GST_EVENT_MASK_FUNCTION (gst_filesrc_get_event_mask,
 )
 
 GST_PAD_QUERY_TYPE_FUNCTION (gst_filesrc_get_query_types,
-  GST_PAD_QUERY_TOTAL,
-  GST_PAD_QUERY_POSITION
+  GST_QUERY_TOTAL,
+  GST_QUERY_POSITION
 )
 
-GST_FORMATS_FUNCTION (gst_filesrc_get_formats,
+GST_PAD_FORMATS_FUNCTION (gst_filesrc_get_formats,
   GST_FORMAT_BYTES
 )
 
@@ -129,7 +138,7 @@ static void		gst_filesrc_get_property	(GObject *object, guint prop_id,
 
 static GstBuffer *	gst_filesrc_get			(GstPad *pad);
 static gboolean 	gst_filesrc_srcpad_event 	(GstPad *pad, GstEvent *event);
-static gboolean 	gst_filesrc_srcpad_query 	(GstPad *pad, GstPadQueryType type,
+static gboolean 	gst_filesrc_srcpad_query 	(GstPad *pad, GstQueryType type,
 		         				 GstFormat *format, gint64 *value);
 
 static GstElementStateReturn	gst_filesrc_change_state	(GstElement *element);
@@ -493,7 +502,6 @@ gst_filesrc_get (GstPad *pad)
     src->seek_happened = FALSE;
     GST_DEBUG (GST_CAT_EVENT, "filesrc sending discont");
     event = gst_event_new_discontinuous (FALSE, GST_FORMAT_BYTES, src->curoffset, NULL);
-    GST_EVENT_DISCONT_NEW_MEDIA (event) = FALSE;
     src->need_flush = FALSE;
     return GST_BUFFER (event);
   }
@@ -723,23 +731,31 @@ gst_filesrc_change_state (GstElement *element)
 }
 
 static gboolean
-gst_filesrc_srcpad_query (GstPad *pad, GstPadQueryType type,
+gst_filesrc_srcpad_query (GstPad *pad, GstQueryType type,
 		          GstFormat *format, gint64 *value)
 {
   GstFileSrc *src = GST_FILESRC (GST_PAD_PARENT (pad));
 
   switch (type) {
-    case GST_PAD_QUERY_TOTAL:
+    case GST_QUERY_TOTAL:
       if (*format != GST_FORMAT_BYTES) {
 	return FALSE;
       }
       *value = src->filelen;
       break;
-    case GST_PAD_QUERY_POSITION:
-      if (*format != GST_FORMAT_BYTES) {
-	return FALSE;
+    case GST_QUERY_POSITION:
+      switch (*format) {
+	case GST_FORMAT_BYTES:
+          *value = src->curoffset;
+          break;
+	case GST_FORMAT_PERCENT:
+	  if (src->filelen == 0)
+	    return FALSE;
+          *value = src->curoffset * GST_FORMAT_PERCENT_MAX / src->filelen;
+          break;
+        default:
+	  return FALSE;
       }
-      *value = src->curoffset;
       break;
     default:
       return FALSE;
