@@ -214,6 +214,9 @@ gst_real_pad_init (GstRealPad *pad)
   pad->formatsfunc 	= gst_pad_get_formats_default;
   pad->querytypefunc 	= gst_pad_get_query_types_default;
 
+  GST_FLAG_SET (pad, GST_PAD_DISABLED);
+  GST_FLAG_UNSET (pad, GST_PAD_NEGOTIATING);
+  
   gst_probe_dispatcher_init (&pad->probedisp);
 }
 
@@ -357,7 +360,6 @@ gst_pad_new_from_template (GstPadTemplate *templ, const gchar *name)
 GstPadDirection
 gst_pad_get_direction (GstPad *pad)
 {
-  g_return_val_if_fail (pad != NULL, GST_PAD_UNKNOWN);
   g_return_val_if_fail (GST_IS_PAD (pad), GST_PAD_UNKNOWN);
 
   return GST_PAD_DIRECTION (pad);
@@ -366,6 +368,7 @@ gst_pad_get_direction (GstPad *pad)
 /**
  * gst_pad_set_active:
  * @pad: the #GstPad to activate or deactivate.
+ * @active: TRUE to activate the pad.
  *
  * Activates or deactivates the given pad.
  */
@@ -375,16 +378,15 @@ gst_pad_set_active (GstPad *pad, gboolean active)
   GstRealPad *realpad;
   gboolean old;
 
-  g_return_if_fail (pad != NULL);
   g_return_if_fail (GST_IS_PAD (pad));
 
-  if (GST_PAD_IS_ACTIVE (pad) == active)
+  old = GST_PAD_IS_ACTIVE (pad);
+
+  if (old == active)
     return;
 
   realpad = GST_PAD_REALIZE (pad);
 
-  old = GST_FLAG_IS_SET (realpad, GST_PAD_DISABLED);
-
   if (active) {
     GST_DEBUG (GST_CAT_PADS, "activating pad %s:%s", 
 	       GST_DEBUG_PAD_NAME (realpad));
@@ -398,6 +400,22 @@ gst_pad_set_active (GstPad *pad, gboolean active)
     g_object_notify (G_OBJECT (realpad), "active");
 }
 
+/**
+ * gst_pad_is_active:
+ * @pad: the #GstPad to query
+ *
+ * Query if a pad is active
+ *
+ * Returns: TRUE if the pad is active.
+ */
+gboolean
+gst_pad_is_active (GstPad *pad)
+{
+  g_return_val_if_fail (GST_IS_PAD (pad), FALSE);
+
+  return !GST_FLAG_IS_SET (pad, GST_PAD_DISABLED);
+}
+
 /**
  * gst_pad_set_name:
  * @pad: a #GstPad to set the name of.
@@ -409,7 +427,6 @@ gst_pad_set_active (GstPad *pad, gboolean active)
 void
 gst_pad_set_name (GstPad *pad, const gchar *name)
 {
-  g_return_if_fail (pad != NULL);
   g_return_if_fail (GST_IS_PAD (pad));
 
   gst_object_set_name (GST_OBJECT (pad), name);
@@ -482,7 +499,6 @@ void
 gst_pad_set_event_function (GstPad *pad,
                             GstPadEventFunction event)
 {
-  g_return_if_fail (pad != NULL);
   g_return_if_fail (GST_IS_REAL_PAD (pad));
 
   GST_RPAD_EVENTFUNC (pad) = event;
@@ -491,19 +507,34 @@ gst_pad_set_event_function (GstPad *pad,
              GST_DEBUG_PAD_NAME (pad), GST_DEBUG_FUNCPTR_NAME (event));
 }
 
+/**
+ * gst_pad_set_event_mask_function:
+ * @pad: a #GstPad to set the event mask function for.
+ * @mask_func: the #GstPadEventMaskFunction to set.
+ *
+ * Sets the given event mask function for the pad.
+ */
 void
 gst_pad_set_event_mask_function (GstPad *pad, 
-                                 GstPadEventMaskFunction mask_function)
+                                 GstPadEventMaskFunction mask_func)
 {
-  g_return_if_fail (pad != NULL);
   g_return_if_fail (GST_IS_REAL_PAD (pad));
 
-  GST_RPAD_EVENTMASKFUNC (pad) = mask_function;
+  GST_RPAD_EVENTMASKFUNC (pad) = mask_func;
 
   GST_DEBUG (GST_CAT_PADS, "eventmaskfunc for %s:%s  set to %s",
-             GST_DEBUG_PAD_NAME (pad), GST_DEBUG_FUNCPTR_NAME (mask_function));
+             GST_DEBUG_PAD_NAME (pad), GST_DEBUG_FUNCPTR_NAME (mask_func));
 }
 
+/**
+ * gst_pad_get_event_masks:
+ * @pad: a #GstPad to get the event mask for.
+ *
+ * Gets the array of eventmasks from the given pad.
+ *
+ * Returns: an array with eventmasks, the list is ended 
+ * with 0
+ */
 const GstEventMask*
 gst_pad_get_event_masks (GstPad *pad)
 {
@@ -523,13 +554,22 @@ gst_pad_get_event_masks (GstPad *pad)
 }
 
 static gboolean
-gst_pad_get_event_masks_dispatcher (GstPad *pad, const GstFormat **data)
+gst_pad_get_event_masks_dispatcher (GstPad *pad, const GstEventMask **data)
 {
-  *data = gst_pad_get_formats (pad);
+  *data = gst_pad_get_event_masks (pad);
 
   return TRUE;
 }
 
+/**
+ * gst_pad_get_event_masks_default:
+ * @pad: a #GstPad to get the event mask for.
+ *
+ * Invokes the default event masks dispatcher on the pad.
+ *
+ * Returns: an array with eventmasks, the list is ended 
+ * with 0
+ */
 const GstEventMask* 
 gst_pad_get_event_masks_default (GstPad *pad)
 {
@@ -541,29 +581,6 @@ gst_pad_get_event_masks_default (GstPad *pad)
   return result;
 }
 
-gboolean
-gst_pad_handles_event (GstPad *pad, GstEventMask *mask)
-{
-  const GstEventMask *masks;
-
-  g_return_val_if_fail (pad != NULL, FALSE);
-  g_return_val_if_fail (mask != NULL, FALSE);
-
-  masks = gst_pad_get_event_masks (pad);
-  if (!masks)
-    return FALSE;
-
-  while (masks->type) {
-    if (masks->type == mask->type &&
-        (masks->flags & mask->flags) == mask->flags)
-      return TRUE;
-
-    masks++;
-  }
-
-  return FALSE;
-}
-
 /**
  * gst_pad_set_convert_function:
  * @pad: a #GstPad to set the convert function for.
@@ -603,6 +620,13 @@ gst_pad_set_query_function (GstPad *pad, GstPadQueryFunction query)
              GST_DEBUG_PAD_NAME (pad), GST_DEBUG_FUNCPTR_NAME (query));
 }
 
+/**
+ * gst_pad_set_query_type_function:
+ * @pad: the #GstPad to set the query type function for.
+ * @type_func: the #GstPadQueryTypeFunction to set.
+ *
+ * Set the given query type function for the pad.
+ */
 void
 gst_pad_set_query_type_function (GstPad *pad, GstPadQueryTypeFunction type_func)
 {
@@ -615,7 +639,16 @@ gst_pad_set_query_type_function (GstPad *pad, GstPadQueryTypeFunction type_func)
              GST_DEBUG_PAD_NAME (pad), GST_DEBUG_FUNCPTR_NAME (type_func));
 }
 
-const GstPadQueryType*
+/**
+ * gst_pad_get_query_types:
+ * @pad: the #GstPad to query
+ *
+ * Get an array of supported queries that can be performed
+ * on this pad.
+ *
+ * Returns: an array of querytypes anded with 0.
+ */
+const GstQueryType*
 gst_pad_get_query_types (GstPad *pad)
 {
   GstRealPad *rpad;
@@ -634,17 +667,26 @@ gst_pad_get_query_types (GstPad *pad)
 }
 
 static gboolean
-gst_pad_get_query_types_dispatcher (GstPad *pad, const GstPadQueryType **data)
+gst_pad_get_query_types_dispatcher (GstPad *pad, const GstQueryType **data)
 {
   *data = gst_pad_get_query_types (pad);
 
   return TRUE;
 }
 
-const GstPadQueryType*
+/**
+ * gst_pad_get_query_types_default:
+ * @pad: the #GstPad to query
+ *
+ * Invoke the default dispatcher for the query types on
+ * the pad.
+ *
+ * Returns: an array of querytypes anded with 0.
+ */
+const GstQueryType*
 gst_pad_get_query_types_default (GstPad *pad)
 {
-  GstPadQueryType *result = NULL;
+  GstQueryType *result = NULL;
 
   gst_pad_dispatcher (pad, (GstPadDispatcherFunction) 
                            gst_pad_get_query_types_dispatcher, &result);
@@ -732,7 +774,8 @@ gst_pad_set_getcaps_function (GstPad *pad,
  * @pad: a #GstPad to set the bufferpool function for.
  * @bufpool: the #GstPadBufferPoolFunction to set.
  *
- * Sets the given bufferpool function for the pad.
+ * Sets the given bufferpool function for the pad. Note that the
+ * bufferpool function can only be set on sinkpads.
  */
 void
 gst_pad_set_bufferpool_function (GstPad *pad,
@@ -740,6 +783,7 @@ gst_pad_set_bufferpool_function (GstPad *pad,
 {
   g_return_if_fail (pad != NULL);
   g_return_if_fail (GST_IS_REAL_PAD (pad));
+  g_return_if_fail (GST_PAD_IS_SINK (pad));
 
   GST_RPAD_BUFFERPOOLFUNC (pad) = bufpool;
   GST_DEBUG (GST_CAT_PADS, "bufferpoolfunc for %s:%s set to %s",
@@ -945,26 +989,22 @@ gst_pad_connect_filtered (GstPad *srcpad, GstPad *sinkpad, GstCaps *filtercaps)
     GST_INFO (GST_CAT_PADS, "*actually* connecting %s:%s and %s:%s",
               GST_DEBUG_PAD_NAME (realsrc), GST_DEBUG_PAD_NAME (realsink));
   }
-  if (GST_RPAD_PEER (realsrc) != NULL)
-  {
+  if (GST_RPAD_PEER (realsrc) != NULL) {
     GST_INFO (GST_CAT_PADS, "Real source pad %s:%s has a peer, failed",
 	      GST_DEBUG_PAD_NAME (realsrc));
     return FALSE;
   }
-  if (GST_RPAD_PEER (realsink) != NULL)
-  {
+  if (GST_RPAD_PEER (realsink) != NULL) {
     GST_INFO (GST_CAT_PADS, "Real sink pad %s:%s has a peer, failed",
 	      GST_DEBUG_PAD_NAME (realsink));
     return FALSE;
   }
-  if (GST_PAD_PARENT (realsrc) == NULL)
-  {
+  if (GST_PAD_PARENT (realsrc) == NULL) {
     GST_INFO (GST_CAT_PADS, "Real src pad %s:%s has no parent, failed",
 	      GST_DEBUG_PAD_NAME (realsrc));
     return FALSE;
   }
-  if (GST_PAD_PARENT (realsink) == NULL)
-  {
+  if (GST_PAD_PARENT (realsink) == NULL) {
     GST_INFO (GST_CAT_PADS, "Real src pad %s:%s has no parent, failed",
 	      GST_DEBUG_PAD_NAME (realsrc));
     return FALSE;
@@ -985,15 +1025,12 @@ gst_pad_connect_filtered (GstPad *srcpad, GstPad *sinkpad, GstCaps *filtercaps)
     realsrc = realsink;
     realsink = temppad;
   }
-  if (GST_PAD_PARENT (realsink) == NULL)
-  if (GST_RPAD_DIRECTION (realsrc) != GST_PAD_SRC)
-  {
+  if (GST_RPAD_DIRECTION (realsrc) != GST_PAD_SRC) {
     GST_INFO (GST_CAT_PADS, "Real src pad %s:%s is not a source pad, failed",
 	      GST_DEBUG_PAD_NAME (realsrc));
     return FALSE;
   }    
-  if (GST_RPAD_DIRECTION (realsink) != GST_PAD_SINK)
-  {
+  if (GST_RPAD_DIRECTION (realsink) != GST_PAD_SINK) {
     GST_INFO (GST_CAT_PADS, "Real sink pad %s:%s is not a sink pad, failed",
 	      GST_DEBUG_PAD_NAME (realsink));
     return FALSE;
@@ -1100,7 +1137,6 @@ gst_pad_get_parent (GstPad *pad)
 GstPadTemplate*
 gst_pad_get_pad_template (GstPad *pad)
 {
-  g_return_val_if_fail (pad != NULL, NULL);
   g_return_val_if_fail (GST_IS_PAD (pad), NULL);
 
   return GST_PAD_PAD_TEMPLATE (pad); 
@@ -1111,7 +1147,10 @@ gst_pad_get_pad_template (GstPad *pad)
  * gst_pad_get_scheduler:
  * @pad: a #GstPad to get the scheduler of.
  *
- * Gets the scheduler of the pad.
+ * Gets the scheduler of the pad. Since the pad does not
+ * have a scheduler of its own, the scheduler of the parent
+ * is taken. For decoupled pads, the scheduler of the peer
+ * parent is taken.
  *
  * Returns: the #GstScheduler of the pad.
  */
@@ -1121,7 +1160,6 @@ gst_pad_get_scheduler (GstPad *pad)
   GstScheduler *scheduler = NULL;
   GstElement *parent;
   
-  g_return_val_if_fail (pad != NULL, NULL);
   g_return_val_if_fail (GST_IS_PAD (pad), NULL);
   
   parent = gst_pad_get_parent (pad);
@@ -1239,7 +1277,7 @@ gst_pad_try_set_caps_func (GstRealPad *pad, GstCaps *caps, gboolean notify)
 
   g_return_val_if_fail (pad != NULL, GST_PAD_CONNECT_REFUSED);
   g_return_val_if_fail (GST_IS_PAD (pad), GST_PAD_CONNECT_REFUSED);
-  
+
   /* if this pad has a parent and the parent is not READY, delay the
    * negotiation */
   if (parent && GST_STATE (parent) < GST_STATE_READY)
@@ -1286,13 +1324,24 @@ gst_pad_try_set_caps_func (GstRealPad *pad, GstCaps *caps, gboolean notify)
   if (notify && GST_RPAD_CONNECTFUNC (pad)) {
     GstPadConnectReturn res;
     gchar *debug_string;
+    gboolean negotiating;
 
     GST_INFO (GST_CAT_CAPS, "calling connect function on pad %s:%s",
             GST_DEBUG_PAD_NAME (pad));
 
+    negotiating = GST_FLAG_IS_SET (pad, GST_PAD_NEGOTIATING);
+
+    /* set the NEGOTIATING flag if not already done */
+    if (!negotiating)
+      GST_FLAG_SET (pad, GST_PAD_NEGOTIATING);
+    
     /* call the connect function */
     res = GST_RPAD_CONNECTFUNC (pad) (GST_PAD (pad), caps);
 
+    /* unset again after negotiating only if we set it  */
+    if (!negotiating)
+      GST_FLAG_UNSET (pad, GST_PAD_NEGOTIATING);
+
     switch (res) {
       case GST_PAD_CONNECT_REFUSED:
 	debug_string = "REFUSED";
@@ -1854,7 +1903,8 @@ gst_pad_recalc_allowed_caps (GstPad *pad)
  * gst_pad_get_bufferpool:
  * @pad: a #GstPad to get the bufferpool from.
  *
- * Gets the bufferpool of the peer pad of the given pad.
+ * Gets the bufferpool of the peer pad of the given pad.Note that
+ * a bufferpool can only be obtained from a srcpad.
  *
  * Returns: the #GstBufferPool, or NULL in case of an error.
  */
@@ -1865,6 +1915,7 @@ gst_pad_get_bufferpool (GstPad *pad)
 
   g_return_val_if_fail (pad != NULL, NULL);
   g_return_val_if_fail (GST_IS_PAD (pad), NULL);
+  g_return_val_if_fail (GST_PAD_IS_SRC (pad), NULL);
    
   peer = GST_RPAD_PEER (pad);
 
@@ -2041,12 +2092,10 @@ gst_pad_save_thyself (GstObject *object, xmlNodePtr parent)
 }
 
 /* FIXME: shouldn't pad and ghost be switched ?
- * FIXME: shouldn't the bin argument be dumped ?
  */
 /**
  * gst_ghost_pad_save_thyself:
  * @pad: a ghost #GstPad to save.
- * @bin: the #bin
  * @parent: the parent #xmlNodePtr to save the description in.
  *
  * Saves the ghost pad into an xml representation.
@@ -2080,7 +2129,7 @@ gst_ghost_pad_save_thyself (GstPad *pad, xmlNodePtr parent)
 void 
 gst_pad_push (GstPad *pad, GstBuffer *buf) 
 {
-  GstRealPad *peer = GST_RPAD_PEER (pad);
+  GstRealPad *peer;
 
   GST_DEBUG_ENTER ("(%s:%s)", GST_DEBUG_PAD_NAME (pad));
 
@@ -2089,11 +2138,19 @@ gst_pad_push (GstPad *pad, GstBuffer *buf)
   if (!gst_probe_dispatcher_dispatch (&(GST_REAL_PAD (pad)->probedisp), GST_DATA (buf)))
     return;
 
+  peer = GST_RPAD_PEER (pad);
+
   if (!peer) {
     g_warning ("push on pad %s:%s but it is unconnected", 
 	       GST_DEBUG_PAD_NAME (pad));
   }
   else {
+    if (!GST_IS_EVENT (buf) && !GST_PAD_IS_ACTIVE (pad)) {
+      g_warning ("push on pad %s:%s but it is not active", 
+	         GST_DEBUG_PAD_NAME (pad));
+      return;
+    }
+
     if (peer->chainhandler) {
       if (buf) {
         GST_DEBUG (GST_CAT_DATAFLOW, 
@@ -2133,13 +2190,13 @@ GstBuffer*
 gst_pad_pull (GstPad *pad) 
 {
   GstRealPad *peer;
-
-  peer = GST_RPAD_PEER (pad);
   
   GST_DEBUG_ENTER("(%s:%s)",GST_DEBUG_PAD_NAME(pad));
 
   g_return_val_if_fail (GST_PAD_DIRECTION (pad) == GST_PAD_SINK, NULL);
 
+  peer = GST_RPAD_PEER (pad);
+
   if (!peer) {
     gst_element_error (GST_PAD_PARENT (pad), 
 		       "pull on pad %s:%s but it was unconnected", 
@@ -2149,6 +2206,7 @@ gst_pad_pull (GstPad *pad)
   else {
     if (peer->gethandler) {
       GstBuffer *buf;
+      gboolean active = GST_PAD_IS_ACTIVE (peer);
 
       GST_DEBUG (GST_CAT_DATAFLOW, "calling gethandler %s of peer pad %s:%s",
                  GST_DEBUG_FUNCPTR_NAME (peer->gethandler), 
@@ -2160,6 +2218,11 @@ gst_pad_pull (GstPad *pad)
         if (!gst_probe_dispatcher_dispatch (&peer->probedisp, GST_DATA (buf)))
           return NULL;
 
+        if (!GST_IS_EVENT (buf) && !active) {
+          g_warning ("pull on pad %s:%s but it is not active", 
+	         GST_DEBUG_PAD_NAME (peer));
+          return NULL;
+        }
         return buf;
       }
 
@@ -2469,7 +2532,7 @@ gst_ghost_pad_init (GstGhostPad *pad)
  *
  * Creates a new ghost pad associated with the given pad, and names it with
  * the given name.  If name is NULL, a guaranteed unique name (across all
- * ghost pads) will be assigned (most likely of the form ghostpad%d).
+ * ghost pads) will be assigned (most likely of the form ghostpad&perc;d).
  *
  * Returns: a new ghost #GstPad, or NULL in case of an error.
  */
@@ -2586,7 +2649,7 @@ gst_pad_event_default_dispatch (GstPad *pad, GstElement *element,
 
     /* for all pads in the opposite direction that are connected */
     if (GST_PAD_DIRECTION (eventpad) != GST_PAD_DIRECTION (pad) 
-     && GST_PAD_IS_USABLE (eventpad)) {
+     && GST_PAD_IS_CONNECTED (eventpad)) {
       if (GST_PAD_DIRECTION (eventpad) == GST_PAD_SRC) {
 	/* increase the refcount */
         gst_event_ref (event);
@@ -2633,6 +2696,15 @@ gst_pad_event_default (GstPad *pad, GstEvent *event)
       gst_element_yield (element);
       break;
     case GST_EVENT_DISCONTINUOUS:
+    {
+      guint64 time;
+	      
+      if (gst_event_discont_get_value (event, GST_FORMAT_TIME, &time)) {
+      	if (gst_element_requires_clock (element) && element->clock) {
+	  gst_clock_handle_discont (element->clock, time); 
+  	}
+      }
+    }
     case GST_EVENT_FLUSH:
     default:
       return gst_pad_event_default_dispatch (pad, element, event);
@@ -2669,7 +2741,7 @@ gst_pad_dispatcher (GstPad *pad, GstPadDispatcherFunction dispatch,
     GstRealPad *int_rpad = GST_PAD_REALIZE (int_pads->data);
     GstRealPad *int_peer = GST_RPAD_PEER (int_rpad);
 
-    if (int_peer && GST_PAD_IS_USABLE (int_peer)) {
+    if (int_peer) {
       res = dispatch (GST_PAD_CAST (int_peer), data);
       if (res)
         break;
@@ -2702,13 +2774,6 @@ gst_pad_send_event (GstPad *pad, GstEvent *event)
 
   rpad = GST_PAD_REALIZE (pad);
 
-  /* don't send events on usuable pads */
-  if (GST_PAD_IS_SINK (rpad) && !GST_PAD_IS_USABLE (rpad)) {
-    GST_DEBUG (GST_CAT_EVENT, "pad %s:%s is not usable", 
-	       GST_DEBUG_PAD_NAME (rpad));
-    return FALSE;
-  }
-
   if (GST_EVENT_SRC (event) == NULL)
     GST_EVENT_SRC (event) = gst_object_ref (GST_OBJECT (rpad));
 
@@ -2816,7 +2881,7 @@ gst_pad_convert (GstPad *pad,
 
 typedef struct 
 {
-  GstPadQueryType type;
+  GstQueryType 	  type;
   GstFormat	 *format;
   gint64	 *value;
 } GstPadQueryData;
@@ -2830,7 +2895,7 @@ gst_pad_query_dispatcher (GstPad *pad, GstPadQueryData *data)
 /**
  * gst_pad_query_default:
  * @pad: a #GstPad to invoke the default query on.
- * @type: the #GstPadQueryType of the query to perform.
+ * @type: the #GstQueryType of the query to perform.
  * @format: a pointer to the #GstFormat of the result.
  * @value: a pointer to the result.
  *
@@ -2839,7 +2904,7 @@ gst_pad_query_dispatcher (GstPad *pad, GstPadQueryData *data)
  * Returns: TRUE if the query could be performed.
  */
 gboolean
-gst_pad_query_default (GstPad *pad, GstPadQueryType type,
+gst_pad_query_default (GstPad *pad, GstQueryType type,
 	               GstFormat *format,  gint64 *value)
 {
   GstPadQueryData data;
@@ -2859,7 +2924,7 @@ gst_pad_query_default (GstPad *pad, GstPadQueryType type,
 /**
  * gst_pad_query:
  * @pad: a #GstPad to invoke the default query on.
- * @type: the #GstPadQueryType of the query to perform.
+ * @type: the #GstQueryType of the query to perform.
  * @format: a pointer to the #GstFormat of the result.
  * @value: a pointer to the result.
  *
@@ -2868,7 +2933,7 @@ gst_pad_query_default (GstPad *pad, GstPadQueryType type,
  * Returns: TRUE if the query could be performed.
  */
 gboolean
-gst_pad_query (GstPad *pad, GstPadQueryType type,
+gst_pad_query (GstPad *pad, GstQueryType type,
 	       GstFormat *format, gint64 *value) 
 {
   GstRealPad *rpad;
@@ -2887,25 +2952,6 @@ gst_pad_query (GstPad *pad, GstPadQueryType type,
   return FALSE;
 }
 
-gboolean
-gst_pad_handles_format (GstPad *pad, GstFormat format)
-{
-  const GstFormat *formats;
-
-  formats = gst_pad_get_formats (pad);
-  if (!formats)
-    return FALSE;
-
-  while (*formats) {
-    if (*formats == format)
-      return TRUE;
-
-    formats++;
-  }
-
-  return FALSE;
-}
-
 static gboolean
 gst_pad_get_formats_dispatcher (GstPad *pad, const GstFormat **data)
 {
@@ -2914,6 +2960,14 @@ gst_pad_get_formats_dispatcher (GstPad *pad, const GstFormat **data)
   return TRUE;
 }
 
+/**
+ * gst_pad_get_formats_default:
+ * @pad: a #GstPad to query
+ *
+ * Invoke the default format dispatcher for the pad.
+ *
+ * Returns: An array of GstFormats ended with a 0 value.
+ */
 const GstFormat*
 gst_pad_get_formats_default (GstPad *pad)
 {
@@ -2925,6 +2979,14 @@ gst_pad_get_formats_default (GstPad *pad)
   return result;
 }
 
+/**
+ * gst_pad_get_formats:
+ * @pad: a #GstPad to query
+ *
+ * Gets the list of supported formats from the pad.
+ *
+ * Returns: An array of GstFormats ended with a 0 value.
+ */
 const GstFormat*
 gst_pad_get_formats (GstPad *pad)
 {
