@@ -30,16 +30,12 @@
 
 G_BEGIN_DECLS
 
-#define GST_TYPE_SCHEDULER \
-  (gst_scheduler_get_type())
-#define GST_SCHEDULER(obj) \
-  (G_TYPE_CHECK_INSTANCE_CAST((obj),GST_TYPE_SCHEDULER,GstScheduler))
-#define GST_SCHEDULER_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_SCHEDULER,GstSchedulerClass))
-#define GST_IS_SCHEDULER(obj) \
-  (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_SCHEDULER))
-#define GST_IS_SCHEDULER_CLASS(obj) \
-  (G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_SCHEDULER))
+#define GST_TYPE_SCHEDULER 		(gst_scheduler_get_type ())
+#define GST_SCHEDULER(obj) 		(G_TYPE_CHECK_INSTANCE_CAST ((obj), GST_TYPE_SCHEDULER, GstScheduler))
+#define GST_IS_SCHEDULER(obj) 		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), GST_TYPE_SCHEDULER))
+#define GST_SCHEDULER_CLASS(klass) 	(G_TYPE_CHECK_CLASS_CAST ((klass), GST_TYPE_SCHEDULER,GstSchedulerClass))
+#define GST_IS_SCHEDULER_CLASS(klass) 	(G_TYPE_CHECK_CLASS_TYPE ((klass), GST_TYPE_SCHEDULER))
+#define GST_SCHEDULER_GET_CLASS(obj) 	(G_TYPE_INSTANCE_GET_CLASS ((obj), GST_TYPE_SCHEDULER, GstSchedulerClass))
 
 typedef enum {
   /* this scheduler works with a fixed clock */
@@ -75,6 +71,8 @@ struct _GstScheduler {
   GList			*clock_receivers;
 
   GList			*schedulers;
+
+  gpointer		dummy[8];
 };
 
 struct _GstSchedulerClass {
@@ -82,7 +80,6 @@ struct _GstSchedulerClass {
 
   /* virtual methods */
   void 			(*setup)		(GstScheduler *sched);
-  gboolean		(*get_preferred_stack)	(GstScheduler *sched, gpointer *stack, gulong *size);
   void 			(*reset)		(GstScheduler *sched);
   void 			(*add_element)		(GstScheduler *sched, GstElement *element);
   void 			(*remove_element)	(GstScheduler *sched, GstElement *element);
@@ -99,12 +96,16 @@ struct _GstSchedulerClass {
   void 			(*pad_disconnect)	(GstScheduler *sched, GstPad *srcpad, GstPad *sinkpad);
   void 			(*pad_select)		(GstScheduler *sched, GList *padlist);
   GstClockReturn	(*clock_wait)		(GstScheduler *sched, GstElement *element,
-		  				 GstClock *clock, GstClockTime time, GstClockTimeDiff *jitter);
+		  				 GstClockID id, GstClockTimeDiff *jitter);
   GstSchedulerState 	(*iterate)		(GstScheduler *sched);
   /* for debugging */
   void 			(*show)			(GstScheduler *sched);
 
-  /* signals go here */
+  /* signals */
+  void                  (*object_sync)          (GstScheduler *sched, GstClock *clock, GstObject *object,
+			                         GstClockID id);
+
+  gpointer		dummy[8];
 };
 
 GType			gst_scheduler_get_type		(void);
@@ -113,7 +114,6 @@ GType			gst_scheduler_get_type		(void);
 
 
 void			gst_scheduler_setup		(GstScheduler *sched);
-gboolean		gst_scheduler_get_preferred_stack(GstScheduler *sched, gpointer *stack, gulong *size);
 void			gst_scheduler_reset		(GstScheduler *sched);
 void			gst_scheduler_add_element	(GstScheduler *sched, GstElement *element);
 void			gst_scheduler_remove_element	(GstScheduler *sched, GstElement *element);
@@ -130,7 +130,7 @@ void			gst_scheduler_pad_connect	(GstScheduler *sched, GstPad *srcpad, GstPad *s
 void			gst_scheduler_pad_disconnect	(GstScheduler *sched, GstPad *srcpad, GstPad *sinkpad);
 GstPad*                 gst_scheduler_pad_select 	(GstScheduler *sched, GList *padlist);
 GstClockReturn		gst_scheduler_clock_wait	(GstScheduler *sched, GstElement *element,
-							 GstClock *clock, GstClockTime time, GstClockTimeDiff *jitter);
+							 GstClockID id, GstClockTimeDiff *jitter);
 gboolean		gst_scheduler_iterate		(GstScheduler *sched);
 
 void			gst_scheduler_use_clock		(GstScheduler *sched, GstClock *clock);
@@ -144,16 +144,12 @@ void			gst_scheduler_show		(GstScheduler *sched);
  * creating schedulers
  *
  */
-#define GST_TYPE_SCHEDULER_FACTORY \
-  (gst_scheduler_factory_get_type ())
-#define GST_SCHEDULER_FACTORY(obj) \
-  (G_TYPE_CHECK_INSTANCE_CAST ((obj), GST_TYPE_SCHEDULER_FACTORY, GstSchedulerFactory))
-#define GST_SCHEDULER_FACTORY_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_CAST ((klass), GST_TYPE_SCHEDULER_FACTORY, GstSchedulerFactoryClass))
-#define GST_IS_SCHEDULER_FACTORY(obj) \
-  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GST_TYPE_SCHEDULER_FACTORY))
-#define GST_IS_SCHEDULER_FACTORY_CLASS(obj) \
-  (G_TYPE_CHECK_CLASS_TYPE ((klass), GST_TYPE_SCHEDULER_FACTORY))
+#define GST_TYPE_SCHEDULER_FACTORY 		(gst_scheduler_factory_get_type ())
+#define GST_SCHEDULER_FACTORY(obj) 		(G_TYPE_CHECK_INSTANCE_CAST ((obj), GST_TYPE_SCHEDULER_FACTORY, GstSchedulerFactory))
+#define GST_IS_SCHEDULER_FACTORY(obj) 		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), GST_TYPE_SCHEDULER_FACTORY))
+#define GST_SCHEDULER_FACTORY_CLASS(klass) 	(G_TYPE_CHECK_CLASS_CAST ((klass), GST_TYPE_SCHEDULER_FACTORY, GstSchedulerFactoryClass))
+#define GST_IS_SCHEDULER_FACTORY_CLASS(klass) 	(G_TYPE_CHECK_CLASS_TYPE ((klass), GST_TYPE_SCHEDULER_FACTORY))
+#define GST_SCHEDULER_FACTORY_GET_CLASS(obj) 	(G_TYPE_INSTANCE_GET_CLASS ((obj), GST_TYPE_SCHEDULER_FACTORY, GstSchedulerFactoryClass))
 
 typedef struct _GstSchedulerFactory GstSchedulerFactory;
 typedef struct _GstSchedulerFactoryClass GstSchedulerFactoryClass;
