@@ -43,17 +43,12 @@ typedef enum {
   GST_THREAD_FLAG_LAST 		= GST_BIN_FLAG_LAST + 4
 } GstThreadState;
 
-
-#define GST_TYPE_THREAD \
-  (gst_thread_get_type())
-#define GST_THREAD(obj) \
-  (G_TYPE_CHECK_INSTANCE_CAST((obj),GST_TYPE_THREAD,GstThread))
-#define GST_THREAD_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_THREAD,GstThreadClass))
-#define GST_IS_THREAD(obj) \
-  (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_THREAD))
-#define GST_IS_THREAD_CLASS(obj) \
-  (G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_THREAD))
+#define GST_TYPE_THREAD 		(gst_thread_get_type())
+#define GST_THREAD(obj) 		(G_TYPE_CHECK_INSTANCE_CAST ((obj), GST_TYPE_THREAD,GstThread))
+#define GST_IS_THREAD(obj) 		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), GST_TYPE_THREAD))
+#define GST_THREAD_CLASS(klass) 	(G_TYPE_CHECK_CLASS_CAST ((klass), GST_TYPE_THREAD,GstThreadClass))
+#define GST_IS_THREAD_CLASS(klass) 	(G_TYPE_CHECK_CLASS_TYPE ((klass), GST_TYPE_THREAD))
+#define GST_THREAD_GET_CLASS(obj) 	(G_TYPE_INSTANCE_GET_CLASS ((obj), GST_TYPE_THREAD, GstThreadClass))
 
 typedef struct _GstThread 	GstThread;
 typedef struct _GstThreadClass 	GstThreadClass;
@@ -62,8 +57,7 @@ struct _GstThread {
   GstBin 	 bin;
 
   GThread 	*thread_id;		/* id of the thread, if any */
-  int 		 sched_policy;
-  int 		 priority;
+  GThreadPriority priority;
   gpointer	*stack;
   guint 	 stack_size;		/* stack size */
   gint		 pid;			/* the pid of the thread */
@@ -72,6 +66,8 @@ struct _GstThread {
   GCond 	*cond;			/* .... used to control the thread */
 
   gint		 transition;		/* the current state transition */
+
+  gpointer 	 dummy[8];
 };
 
 struct _GstThreadClass {
@@ -79,12 +75,16 @@ struct _GstThreadClass {
 
   /* signals */
   void	(*shutdown)	(GstThread *thread);
+
+  gpointer 	 dummy[8];
 };
 
 GType 	gst_thread_get_type	(void);
 
 GstElement*	gst_thread_new		(const gchar *name);
 
+void		gst_thread_set_priority (GstThread *thread, GThreadPriority priority);
+
 G_END_DECLS
 
 
