@@ -199,12 +199,12 @@ print_event_masks (const GstEventMask *masks)
 }
 
 static void 
-print_query_types (const GstPadQueryType *types) 
+print_query_types (const GstQueryType *types) 
 {
   GType query_type;
   GEnumClass *klass;
 
-  query_type = gst_pad_query_type_get_type();
+  query_type = gst_query_type_get_type();
   klass = (GEnumClass *) g_type_class_ref (query_type);
 
   while (types && *types) {
@@ -589,9 +589,9 @@ print_element_info (GstElementFactory *factory)
     g_print ("  none\n");
   }
 
-  g_print ("\nCaching capabilities:\n");
-  if (gst_element_is_cachable (element)) {
-    g_print ("  element can do caching\n");
+  g_print ("\nIndexing capabilities:\n");
+  if (gst_element_is_indexable (element)) {
+    g_print ("  element can do indexing\n");
   }
   else {
     g_print ("  none\n");
@@ -817,10 +817,10 @@ print_element_list (void)
         g_print ("%s:  %s: %s\n", plugin->name, 
 	        GST_PLUGIN_FEATURE_NAME (factory), factory->longdesc);
       }
-      else if (GST_IS_CACHE_FACTORY (feature)) {
-        GstCacheFactory *factory;
+      else if (GST_IS_INDEX_FACTORY (feature)) {
+        GstIndexFactory *factory;
 
-        factory = GST_CACHE_FACTORY (feature);
+        factory = GST_INDEX_FACTORY (feature);
         g_print ("%s:  %s: %s\n", plugin->name, 
 	        GST_PLUGIN_FEATURE_NAME (factory), factory->longdesc);
       }
@@ -862,7 +862,7 @@ print_plugin_info (GstPlugin *plugin)
   gint num_autoplug = 0;
   gint num_types = 0;
   gint num_schedulers = 0;
-  gint num_caches = 0;
+  gint num_indexes = 0;
   gint num_other = 0;
   
   g_print ("Plugin Details:\n");
@@ -893,12 +893,12 @@ print_plugin_info (GstPlugin *plugin)
       g_print ("  %s: %s\n", GST_OBJECT_NAME (factory), factory->longdesc);
       num_autoplug++;
     }
-    else if (GST_IS_CACHE_FACTORY (feature)) {
-      GstCacheFactory *factory;
+    else if (GST_IS_INDEX_FACTORY (feature)) {
+      GstIndexFactory *factory;
 
-      factory = GST_CACHE_FACTORY (feature);
+      factory = GST_INDEX_FACTORY (feature);
       g_print ("  %s: %s\n", GST_OBJECT_NAME (factory), factory->longdesc);
-      num_caches++;
+      num_indexes++;
     }
     else if (GST_IS_TYPE_FACTORY (feature)) {
       GstTypeFactory *factory;
@@ -935,8 +935,8 @@ print_plugin_info (GstPlugin *plugin)
     g_print ("  +-- %d types\n", num_types);
   if (num_schedulers > 0)
     g_print ("  +-- %d schedulers\n", num_schedulers);
-  if (num_caches > 0)
-    g_print ("  +-- %d caches\n", num_caches);
+  if (num_indexes > 0)
+    g_print ("  +-- %d indexes\n", num_indexes);
   if (num_other > 0)
     g_print ("  +-- %d other objects\n", num_other);
   
